Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MergeMaps ¶
MergeMaps takes two maps and returns a combined map, where KV pairs in the second map arg take precedence over the first.
func ValidPresets ¶ added in v1.4.0
func ValidPresets() []string
ValidPresets returns the sorted list of available preset names.
Types ¶
type Config ¶
type Config struct {
Juju jujuConfig `mapstructure:"juju"`
Providers providerConfig `mapstructure:"providers"`
Host hostConfig `mapstructure:"host"`
// The following are added at runtime according to CLI flags
Overrides ConfigOverrides `mapstructure:"overrides"`
Status Status `mapstructure:"status"`
Verbose bool `mapstructure:"verbose" yaml:"-"`
Trace bool `mapstructure:"trace" yaml:"-"`
DryRun bool `mapstructure:"-" yaml:"-"`
}
Config represents concierge's configuration format.
type ConfigOverrides ¶
type ImageRegistryConfig ¶ added in v1.4.0
type ImageRegistryConfig struct {
URL string `mapstructure:"url"`
Username string `mapstructure:"username"`
Password string `mapstructure:"password"`
}
ImageRegistryConfig represents configuration for an image registry mirror.
type SnapConfig ¶
type SnapConfig struct {
// Channel is the channel from which to install the snap. If omitted, the default behaviour is decided by snapd.
Channel string `mapstructure:"channel"`
// Connections is a list of snap connections to form.
Connections []string `mapstructure:"connections"`
}
SnapConfig represents the configuration for a specific snap to be installed.
Click to show internal directories.
Click to hide internal directories.